@@ -100,8 +100,8 @@ light_theme = {'axes.grid': True,
                'xtick.color': '#000000',
                'ytick.color': '#000000',
                'text.color': '#000000',
-               'grid.color': '#E5E5E5',
-               'figure.facecolor': '#FBFBFB',
+               'grid.color': '#ECECE5',
+               'figure.facecolor': '#FCFCFA',
                'axes.prop_cycle': cycler('color', linecolors),
                'savefig.bbox': None,
                'savefig.directory': '~',
@@ -157,9 +157,10 @@ for tname in ('light', 'white-background', 'dark', 'matplotlib', 'ggplot',
                       'ytick.labelsize': 9, 'axes.labelsize': 9,
                       'axes.titlesize': 13})
     elif tname.startswith('seaborn'):
-        theme.update(matplotlib.style.library['seaborn'])
+        theme.update(matplotlib.style.library['seaborn-v0_8'])
         if '-' in tname:
-            theme.update(matplotlib.style.library[tname])
+            sname = tname.replace('seaborn', 'seaborn-v0_8')
+            theme.update(matplotlib.style.library[sname])
     elif tname in matplotlib.style.library:
         theme.update(matplotlib.style.library[tname])
     Themes[tname.lower()] = theme
@@ -744,10 +745,13 @@ class PlotConfig:
             self.axes_style = style
 
         try:
-            ax = self.canvas.figure.get_axes()[0]
+            axes = self.canvas.figure.get_axes()
+            ax = axes[0]
         except AttributeError:
             return
 
+
+
         for tline in (ax.xaxis.get_majorticklines() + ax.yaxis.get_majorticklines()):
             tline.set_color(rcParams['xtick.color'])
             tline.set_markeredgewidth(rcParams['xtick.major.width'])
@@ -783,6 +787,10 @@ class PlotConfig:
             ax.spines['left'].set_visible(False)
             ax.spines['right'].set_visible(False)
 
+        # if 2 y-axes, don't draw ticks on right side for axes[0]
+        if len(axes) > 1:
+            axes[0].yaxis.set_tick_params(right=False)
+            axes[1].yaxis.set_tick_params(left=False)
 
         if not delay_draw:
             self.canvas.draw()
